unit rasunit;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  ExtCtrls, StdCtrls, RasDial, Buttons;

type
  TMainForm = class(TForm)
    ComboBoxEntries: TComboBox;
    Label1: TLabel;
    ButtonProperties: TButton;
    ButtonNew: TButton;
    ButtonDial: TButton;
    PanelInfo: TPanel;
    RasDialer: TRasDialer;
    ButtonDisconnect: TButton;
    ButtonPhonebook: TButton;
    OpenDialog: TOpenDialog;
    Memo1: TMemo;
    CheckBox1: TCheckBox;
    CheckBox2: TCheckBox;
    procedure ButtonNewClick(Sender: TObject);
    procedure ButtonPropertiesClick(Sender: TObject);
    procedure RasDialerStateChange(Sender: TObject; NewState,
      OldState: TRasState);
    procedure RasDialerConnnect(Sender: TObject);
    procedure RasDialerDisconnect(Sender: TObject);
    procedure ButtonDialClick(Sender: TObject);
    procedure ButtonDisconnectClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure ButtonPhonebookClick(Sender: TObject);
    procedure ComboBoxEntriesChange(Sender: TObject);
    procedure CheckBox1Click(Sender: TObject);
    procedure RasDialerCloseQuery(Sender: TObject; var CanClose: Boolean);
  private
    { Private declarations }
    procedure LoadPhonebook;
  public
    { Public declarations }
  end;

var
  MainForm: TMainForm;

implementation

{$R *.DFM}

procedure TMainForm.LoadPhonebook;
var
 ix: integer;
begin
 with RasDialer do begin
  ComboBoxEntries.Clear;
  for ix:=0 to EntryCount-1 do
  ComboBoxEntries.Items.Add(Entries[ix]);
  if 0<EntryCount
  then ComboBoxEntries.ItemIndex:=ComboBoxEntries.Items.IndexOf(EntryName);
  ButtonDial.Enabled:=0<EntryCount;
 end; { with }
end;

procedure TMainForm.ButtonNewClick(Sender: TObject);
begin
 RasDialer.CreatePhonebookEntry;
 RasDialer.Refresh;
 LoadPhonebook;
end;

procedure TMainForm.ButtonPropertiesClick(Sender: TObject);
begin
 RasDialer.EditPhonebookEntry(ComboBoxEntries.Text);
 RasDialer.Refresh;
 LoadPhonebook;
end;

procedure TMainForm.RasDialerStateChange(Sender: TObject; NewState,
  OldState: TRasState);
begin
 with RasDialer do PanelInfo.Caption:=StateString(NewState);
end;

procedure TMainForm.RasDialerConnnect(Sender: TObject);
var
 s: string;
begin
 PanelInfo.Caption:='Now connected to ['+RasDialer.EntryName+']';
 CheckBox2.Enabled:=RasDialer.IsShared;
 CheckBox1.Enabled:=False;
 ButtonDisconnect.Enabled:=True;
 { Information Panel - This is quick and dirty code !! }
 with RasDialer,Memo1 do begin
  Clear;
  Lines.Add('Connection:');
  Lines.Add('DeviceType='+DeviceType);
  Lines.Add('DeviceName='+DeviceName);
  Lines.Add('');
  Lines.Add('Protocols Supported:');
  s:=IntToStr(Lines.Count);
  if rpIP in Protocols
  then s:=s+') IP Support'
  else if 0<IpError
       then s:=s+') NO IP Support. Rc='+IntToStr(IpError)
       else s:='';
  if s<>'' then Lines.Add(s);
  s:=IntToStr(Lines.Count);
  if rpIPX in Protocols
  then s:=s+') IPX Support'
  else if 0<IpxError
       then s:=s+') NO IPX Support. Rc='+IntToStr(IpxError)
       else s:='';
  if s<>'' then Lines.Add(s);
  s:=IntToStr(Lines.Count);
  if rpNetBEUI in Protocols
  then s:=s+') NetBios Support'
  else if 0<NetBiosError
       then s:=s+') NO NetBios Support. Rc='+IntToStr(NetBiosError)
       else s:='';
  if s<>'' then Lines.Add(s);
 end; { with }
end;

procedure TMainForm.RasDialerDisconnect(Sender: TObject);
begin
 PanelInfo.Caption:='Disconnected from ['+RasDialer.EntryName+']';
 ButtonDisconnect.Enabled:=False;
 ButtonDial.Enabled:=True;
 CheckBox1.Enabled:=True;
 CheckBox2.Enabled:=False;
end;

procedure TMainForm.ButtonDialClick(Sender: TObject);
begin
 try
  ButtonDial.Enabled:=False;
  with RasDialer do begin
   EntryName:=ComboBoxEntries.Text;
   Connect;
   while Working do Application.ProcessMessages;
   if not Connected then raise Exception.Create('Error in RasConnect: '+ErrorString(LastError));
   PanelInfo.Caption:=Format('IP Address:%s, Server IP Address: %s',[IpAddress,IpServerAddress]);
  end; { with }
 except
  ButtonDial.Enabled:=True;
  raise;  { reraise the exception }
 end; { try }
end;

procedure TMainForm.ButtonDisconnectClick(Sender: TObject);
begin
 RasDialer.Disconnect;
end;

procedure TMainForm.FormCreate(Sender: TObject);
var
 s: string;
 ix: integer;
begin
 Caption:='RasDialer '+RasDialer.Version;
 RasDialer.Phonebook:='C:\WINNT\SYSTEM32\RAS\RASPHONE.PBK';  { Only for Windows NT }
 LoadPhonebook;
 with RasDialer.Connections do begin
  Refresh;
  Memo1.Clear;
  Memo1.Lines.Add('Active RAS Connections:');
  if Count=0
  then Memo1.Lines.Add('<None>')
  else for ix:=0 to Count-1 do
        with Items[ix] do
         Memo1.Lines.Add(IntToHex(Handle,8)+' '+DeviceType+' '+DeviceName);
 end; { with }
end;

procedure TMainForm.ButtonPhonebookClick(Sender: TObject);
var
 s: string;
 l: integer;
begin
 with OpenDialog do begin
  SetLength(s,100);
  l:=GetWindowsDirectory(@s[1],100);
  SetLength(s,l);
  InitialDir:=s;
  if Execute
  then begin
        RasDialer.Phonebook:=Filename;
        LoadPhonebook;
       end; { if }
 end; { with }
end;

procedure TMainForm.ComboBoxEntriesChange(Sender: TObject);
begin
 RasDialer.EntryName:=ComboBoxEntries.Text;
end;

procedure TMainForm.CheckBox1Click(Sender: TObject);
begin
 with RasDialer do
  if CheckBox1.Checked
  then Options:=Options+[roShareConnection]
  else Options:=Options-[roShareConnection]
end;

procedure TMainForm.RasDialerCloseQuery(Sender: TObject;
  var CanClose: Boolean);
begin
 with Sender as TRasDialer do
  if IsShared then CanClose:=not CheckBox2.Checked;
end;

end.
